import { CurrencyPipe } from '@angular/common';
import { HttpClient } from '@angular/common/http';
import { ChangeDetectionStrategy, Component, inject, OnInit, signal } from '@angular/core';
import { AnimatedNumberComponent } from '@blackjack/components/animated-number/animated-number.component';
import { GameInfoComponent } from '@blackjack/components/game-info/game-info.component';
import { AuthService } from '@service/auth.service';
import { AudioService } from '@shared/services/audio.service';

@Component({
  selector: 'app-coinflip',
  standalone: true,
  imports: [AnimatedNumberComponent, CurrencyPipe],
  templateUrl: './coinflip.component.html',
  styleUrl: './coinflip.component.css',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export default class CoinflipComponent implements OnInit {
  currentBet = signal(0);
  balance = signal(0);
  gameInProgress = signal(false);
  isActionInProgress = signal(false);
  audioService = inject(AudioService);
  authService = inject(AuthService);

  private http = inject(HttpClient);

  setBetAmount(amount: number) {
    this.currentBet.update((current) => current * amount);
  }

  onNewGame(bet: number): void {
    this.isActionInProgress.set(true);
    this.audioService.playBetSound();
    this.currentBet.set(bet);
  }

  betHeads() {
    this.gameInProgress.set(true);
  }
  betTails() {
    this.gameInProgress.set(true);
  }

  ngOnInit(): void {
    // Subscribe to user updates for real-time balance changes
    this.authService.userSubject.subscribe((user) => {
      if (user) {
        this.balance.set(user.balance);
      }
    });
  }
}
